#!/bin/sh
# Install GigA+ under CentOS 6,7
# This script is part of GigA+ (C) 2017 Pavel Cherenkov

##
# Subroutines
##

get_osid()
{
    issue='?'; distro='?'; version='?'; arch='?'

    ostype=`uname -s`
    case "${ostype}" in
        Linux)      issue=`sed -n '1p' /etc/issue`
                    distro=`sed -n '1p' /etc/issue | cut -d' ' -f1`

                    case "${distro}" in
                        Debian|CentOS)  version=`sed -n '1p' /etc/issue | cut -d' ' -f3` ;;
                        Ubuntu)         version=`sed -n '1p' /etc/issue | cut -d' ' -f2` ;;
                    esac

                    if [ -f /etc/redhat-release ]; then
                        if [ -z "$distro" -o "\S" = "$distro" ]; then
                            distro=`sed -n '1p' /etc/redhat-release | cut -d' ' -f1`
                            version=`sed -n '1p' /etc/redhat-release | cut -d' ' -f4 | cut -d'.' -f1`
                        fi
                    fi
        ;;
        FreeBSD)    issue=`uname -sr`
                    distro=${ostype}
                    version=`echo ${issue} | awk '{print $2}' | cut -d'-' -f1`
        ;;
    esac

    marc=`uname -m`
    case "$marc" in
        i386|i686)      arch='i386';  rarch=$arch  ;;
        amd64|x86_64)   arch='amd64'; rarch='x86_64' ;;
        armv7l)         arch='armhf'; rarch=$arch ;;
    esac

    if [ "systag" = "${1:-''}" ]; then
        echo "\"${distro} ${version} ${ostype} (${arch})\""
    elif [ "terse" = "${1:-''}" ]; then
    echo "${distro} ${version}"
    else
        echo "${ostype},${distro},${version},${arch},${rarch}"
    fi
}


centos6_prep()
{
    rpmpath=$1
    echo >&2 "Preparing to install ${rpmpath:?} under CentOS 6"

    if [ ! -f /etc/yum.repos.d/epel.repo ]; then
        yum -y install epel-release || exit 1
        yum makecache fast
    else
        echo >&2 "EPEL already installed"
    fi
}


centos7_prep()
{
    rpmpath=$1
    echo >&2 "Preparing to install ${rpmpath:?} under CentOS 7"

    if [ ! -f /etc/yum.repos.d/epel.repo ]; then
        yum -y install epel-release || exit 1
        yum makecache fast
    else
        echo >&2 "EPEL already installed"
    fi
}


##
# Main
##

if [ $# -ne 1 ]; then
    echo >&2 "Usage: $0 gigaplus-rpm-path"
    exit 1
fi

pkg_path=${1:?}
if [ ! -f ${pkg_path} ]; then
    echo >&2 "$0: cannot find ${pkg_path}"
fi

if [ $EUID -ne 0 ]; then
    echo >&2 "%0 must be run as root."
    exit 1
fi

osinfo=`get_osid terse`
distro=`echo $osinfo | cut -d' ' -f1`
mver=`echo $osinfo | cut -d' ' -f2 | cut -d. -f1`

case "${distro}" in
    CentOS)
        case "${mver}" in
            6) centos6_prep ${pkg_path} || exit 2 ;;
            7) centos7_prep ${pkg_path} || exit 2 ;;
            *) echo >&2 "${distro} ${mver} not supported"; exit 1 ;;
        esac
    ;;
    *) echo >&2 "${distro} not supported"; exit 1 ;;
esac

yum --nogpgcheck localinstall ${pkg_path} && echo >&2 "Installation completed!"

# __EOF__

