#!/usr/bin/env bash
# @(#) Update host-specific sensor value in LBDB.

if [ $# -lt 1 ]; then
    echo >&2 "Usage: $0 [-tmout {sec}] [-host {alias}] sensor-name"
    exit 1
fi

tmout_sec=60
host_alias=$(hostname)

if [ '-tmout' = "$1" ]; then
    tmout_sec=`expr ${2:?} + 0`
    shift 2
fi
if [ '-host' = "$1" ]; then
    host_alias=${2:?}
    shift 2
fi

sensor_name=${1}
if [ -z "$sensor_name" ]; then
    echo >&2 "$0 MUST supply sensor name"
    exit 1
fi

db_key="S:${sensor_name:?}:${host_alias:?}"
echo >&2 "$0: [${db_key}] tmout=${tmout_sec} sec"

while read numval; do
    if ! expr $numval + 0 >/dev/null 2>&1; then
        echo >&2 "WARNING: invalid val=[$numval], ignoring"
        continue
    fi

    echo >&2 $numval
    echo "SET ${db_key} $numval EX ${tmout_sec}"
done

echo >&2 "$0: done"

# __EOF__

