#!/bin/sh
# @(#) channel spec for Gigapxy VSM
# All variables have cha_ prefix not to clash with other scripts

# Clients must reference channel using this unique ID.
cha_ID="sample1-hd"

# If your stream is MPTS, select program to work on (decimal PID).
# cha_PRGID=90

# Path to gxpm (domain) socket.
cha_GPM="/opt/gxa/run/gxpm-S.sock"

# ffmpeg-style URL for channel source.
cha_URL="http://acme.tv:4046/udp/239.1.2.30:33333"

# Path to data root (channel name will be added to this path).
cha_ROOT="/opt/gxa/channel"

# Channel-specific prefix to playlist items.
#
# NB: if leaving commented out, do NOT forget to
#     set gpm.item_url_prefix setting in gigaplus.conf.
#
# cha_PFX="http://your.host:8181/channel/"

# Paths to (sharded) subdirectories.
# Full path would become: $root/$shard/$cha_ID
#
# cha_SHARDS="vol1:vol2:vol3"

# How much data in seconds should we keep?
# Segments will be rotated according to this limit.
#
# Example: 259200 sec = 3 days
#
cha_CAPACITY=600

# Duration of a segment (in seconds).
# (Optional, default=5).
#
cha_DURATION=6

# Allow N critical errors w/o quitting the app.
# Irregularities in input cause libav to produce "critical errors"
# that require either an exit(3) of gxseg(1) or an internal
# restart of the app. N restarts will be performed before exit(3).
#
# NB: set to -1 to always re-start and never exit(3). Restarts
#     are known cause memory leaks (thus the fewer the better),
#     but are *fast* compared to app exits.
#
cha_MAX_CERR=10

# Transcode using these (ffmpeg) options.
# IMPORTANT: do test, as in: ffmpeg -i http://source/channel ${cha_TRANSOPT} -f mpegts out.ts
#
# cha_TRANSOPT="-map 0:0 -map 0:1 -map 0:2 -map 0:3 -vcodec copy -c:a aac -c:s copy"

# Roll over (to a backup instance of gxseg) every N seconds.
# NB: this is done to avoid libav-specific issue with PTS inconsistencies
# and stalling of data streams.
#
# NB: the preferred way is to use force-rollover.sh script, scheduling
# roll-overs in low-activity hours via cron(8).
#
# cha_ROLLOVER=3600

# Root for segments generated by backup gxseg instance before rollover.
#
cha_FALSE_ROOT=/opt/gxa/bufd

# Timestamp mask as per strftime(3) for segment subdirs.
cha_GRAN_MASK='%Y%m%d-%H'

# Number of items to keep in the manifest.
# Unless set here, this value is automatically calculated as cha_CAPACITY / cha_DURATION + 10.
# If set to 0, the value is NOT set and no manifest is going to be kept.
#
# cha_MITEMS=50

# Channel size in MB (total size of all files) at full load
# (after cha_CAPACITY seconds passed).
#
# Note: hos won't archive segments until this size is reached.
#
cha_LMARK_DISKSIZE=1200

# Maximum allowable size (in MB) for a channel.
# An alarm will be triggered if this size is exceeded.
#
cha_HMARK_DISKSIZE=2500

# Notify administrator (by this email) on crucial events.
cha_ADMIN_EMAIL='whoeverminds@the.shop'

# vim: syntax=sh
# __EOF__

