#!/bin/sh
# @(#) Sample Gigapxy authorization handler using A1P protocol.


# Write message into debug log (or STDERR).
dbg_msg()
{
    case "${os}" in
        'Linux') tstamp=`date +"%Y-%m-%d %H:%M:%S.%N %Z"`;;
        *) tstamp=`date +"%Y-%m-%d %H:%M:%S %Z"` ;;
    esac

    if [ -n "${logfile}" ]; then
        echo >>${logfile} "${tstamp} pid=$$\t$@"
    else
        echo >&2 "${tstamp} pid=$$\t$@"
    fi
}


# Perform graceful exit.
exit_app()
{
    dbg_msg "$0 exited $1"
    exit 1
}


# Authenticate using MD5 hash on auth=tkn tail of the channel url.
auth_ok()
{
    peer_ip=`echo ${1:?} | cut -d':' -f1`
    channel=`echo ${2:?} | cut -d'?' -f1`
    auth_tkn=`echo ${2:?} | cut -d'?' -f2 | sed 's/auth=//'`

    if [ "localhost" = "$peer_ip" -o "127.0.0.1" = "$peer_ip" ]; then
        dbg_msg "Localhost request: PASS"
        return 0
    fi

    phrase="Greetings from ${peer_ip}! Give me ${channel}, please."
    # dbg_msg "phrase=[${phrase}], tkn=${auth_tkn}"

    case "${os}" in
        'Linux')    hash=`echo -n ${phrase} | md5sum | cut -d' ' -f1` ;;
        'FreeBSD')  hash=`echo -n ${phrase} | md5` ;;
    esac

    # dbg_msg "hash=${hash}, tkn=${auth_tkn}"

    if [ "${hash}" != "${auth_tkn}" ]; then
        return 1
    fi

    return 0
}


###
# Read requests from STDIN, respond via STDOUT.
###

os=`uname`

if [ $# -lt 1 ]; then
    echo >&2 "Usage: $0 logfile|-"
    exit 1
fi


logfile=${1:-}
case "${logfile}" in
'-')        logfile='/dev/null';;
'stderr')   logfile=;;
esac

parent_pid=$PPID  # parent of this script shell

dbg_msg "$0 started, parent=${parent_pid}"
trap 'exit_app KILLED;' HUP INT QUIT PIPE TERM

while read qtag peer_ipport cha_src cli_dst; do
        dbg_msg "Got ${qtag} request for ${peer_ipport} ${cha_src}"
        if echo $qtag | grep -q '^A[0-9]\{1,9\}$'; then
            if auth_ok ${peer_ipport} ${cha_src}; then
                rc=0; status="ALLOWED"
            else
                rc=111; status="DENIED"
            fi

            dbg_msg "${status} tag=${qtag} peer=${peer_ipport} cha=${cha_src} cli=${cli_dst}"
            echo "${qtag} ${rc}"
        else
            dbg_msg "Invalid query ID: [$qtag], request ignored."
        fi
done

exit_app 'OK'

# vim: syntax=sh

