#!/bin/sh
# @(#) Sample Gigapxy B2P-protocol authorization handler.
#
# Use as a template to change/adapt to your needs.
#

# Globals (to make code shorter):
g_qtag=
g_fields=
g_url=
g_src=
g_dst=
g_peer=
g_agent=

g_response=

##
# Subroutines:
#

# Write message into debug log (or STDERR).
dbg_msg()
{
    case "${os}" in
        'Linux') tstamp=`date +"%Y-%m-%d %H:%M:%S.%N %Z"`;;
        *) tstamp=`date +"%Y-%m-%d %H:%M:%S %Z"` ;;
    esac

    if [ -n "${logfile}" ]; then
        echo >>${logfile} "${tstamp} pid=$$\t$@"
    else
        echo >&2 "${tstamp} pid=$$\t$@"
    fi
}


# Perform graceful exit.
exit_app()
{
    dbg_msg "$0 exited $1"
    exit 1
}


##
# Process request, compile response.
#
# IN:   nothing (using globals).
# OUT:  fill out g_response.
#
# @return 0 if request approved, non-zero if denied.
#
process_request()
{
    # Check URL for a specific type, make decision based on extracted operator ID.
    #
    oid=`echo $g_url | sed 's!^.*/operatorid/!!g' | cut -d'?' -f1`
    if [ -n "$oid" ]; then
        case $oid in
            'f3404'|'89756')
                # Overwrite source (skip auth status, assumed OK):
                g_response="$g_qtag S udp://224.0.2.26:5050"
                return 0
                ;;
            8*)
                # Overwrite destination (specify auth status):
                g_response="$g_qtag SDr udp://224.0.2.26:5050 http://192.168.1.50:4455 0"
                return 0
                ;;
        esac
    fi

    # Decisions based on global parameters:
    #
    peer_ip=`echo $g_peer | cut -d':' -f1`
    if [ "localhost" = "$peer_ip" -o "127.0.0.1" = "$peer_ip" ]; then
        g_response="$g_qtag r 0" # approved
        return 0
    fi

    auth_tkn=`echo $g_src | grep '?auth=' | cut -d'?' -f2 | sed 's/auth=//'`
    if [ "sezam-kazaam" = "$auth_tkn" ]; then
        g_response="$g_qtag r 0" # approved
        return 0
    fi

    dbg_msg "Denying [$g_qtag] by default"
    g_response="$g_qtag r 111"

    return 0
}


###
# main: read requests from STDIN, respond via STDOUT.
###

os=`uname`

if [ $# -lt 1 ]; then
    echo >&2 "Usage: $0 logfile|-"
    exit 1
fi


logfile=${1:-}
case "${logfile}" in
'-')        logfile='/dev/null';;
'stderr')   logfile=;;
esac

parent_pid=$PPID  # parent of this script's shell

dbg_msg "$0 started, parent=${parent_pid}"
trap 'exit_app KILLED;' HUP INT QUIT PIPE TERM

# These are the fields in the order specified
# in ws.auth.b_fields
expected="USDPA"


# Read message fields in the order expected/specified.
# Tag & field mask come first, always.
#
while read g_qtag g_fields g_url g_src g_dst g_peer g_agent; do
        g_response='' # to be filled out

        while [ -z ${g_response} ]; do
            if ! echo $g_qtag | grep -q '^B[0-9]\{1,9\}$'; then
                dbg_msg "Wrong protocol tag: $g_qtag"
                g_response="$g_qtag 111"
                break
            fi

            if [ "$g_fields" != "$expected" ]; then
                dbg_msg "Was expecting [$expected] as fields, got [$g_fields]"
                g_response="$g_qtag r 111"
                break
            fi

            dbg_msg "${g_qtag}: url=[$g_url] src=$g_src, dst=$g_dst, peer=$g_peer agent=$g_agent"
            process_request; rc=$?
            break
        done

        dbg_msg "Response=$g_response"

        # Response goes out to gws:
        echo $g_response
done

exit_app 'OK'

# vim: syntax=sh

