-- Add new segment-URL
--
-- IN: KEYS[1] = KEY; Example: 'v1/20170504-03/33303992.ts'.
-- IN: ARGV[1] = segment URL; Example: 'http://acme.io:1717/segs/v1/20170504-03/33303992.ts'.
-- IN: ARGV[2] = expiration UNIX time (in seconds) or 0 if none; Example: 1454337928.

local locK = "LOC:" .. KEYS[1]
local posK = "POS:" .. KEYS[1]

local loc_exists = redis.call("EXISTS", locK)

local added = redis.call("ZADD", locK, "NX", 1, ARGV[1])
if added ~= 1 then
    return "#err: cannot add URL to " .. locK .. ", a duplicate?"
end

local xtime = tonumber(ARGV[2])

if loc_exists <= 0 and xtime > 0 then
    local expired = redis.call("EXPIREAT", locK, ARGV[2])
    if expired ~= 1 then
        return "#err: failed set expiration for " .. locK
    end
end

local pos_set = redis.call("SET", posK, -1, "NX")
if pos_set and xtime > 0 then
    local expired = redis.call("EXPIREAT", posK, ARGV[2])
    if expired ~= 1 then
        return "#err: failed set expiration for " .. posK
    end
end

return "OK " .. KEYS[1]

-- EOF --

