#!/usr/bin/env bash
# @(#) Load scripts into Load-balancer DB.
#

##
# Functions
#

msg()
{
    tstamp=$(date +"%F %Z %H:%M:%S")
    echo >&2 $tstamp ${APP} ${PID} $@
}

warn()
{
    msg "WARNING: $@"
}


err()
{
    msg $@
    exit 1
}

##
# Main
#

config_script="lbdb.config"

if [ $# -lt 1 ]; then
    echo >&2 "Usage: $0 [-n] lua"

    if [ ! -f "${config_script}" ]; then
        cat <<_EOT
You may wish to define:

LBDB_HOST       = DB hostname
LBDB_PORT       = DB port
LBDB_LUA_DIR    = source directory
LBDB_SHA1_DIR   = destination directory

in ${config_script}
_EOT
    fi

    exit 1
fi

if [ "-n" = "$1" ]; then
    shift; DOIT='echo'
    warn "dry-run mode"
fi


[ -f "${config_script}" ] && . ${config_script}

: ${LBDB_HOST:='127.0.0.1'}
: ${LBDB_PORT:=6379}
: ${LBDB_LUA_DIR:=.}
: ${LBDB_SHA1_DIR:=.}

type redis-cli 2>/dev/null >&2 || err "redis client must be available"

errors=0
lua_scripts='add_url del_url next_url mbget_url'
for fname in `echo $lua_scripts`; do
    fpath=${LBDB_LUA_DIR}/${fname}.lua
    [ -f "$fpath" ] || err "missing ${fpath}"

    sha1_signature="${LBDB_SHA1_DIR:?}/${fname}.sha1"
    if [ -n "$DOIT" ]; then
        $DOIT redis-cli -h ${LBDB_HOST:?} -p ${LBDB_PORT:?} SCRIPT LOAD "cat ${fpath}" \> ${sha1_signature}; rc=$?
    else
        msg "$fpath to ${LBDB_HOST:?}:${LBDB_PORT}"
        cat ${fpath} | redis-cli -h ${LBDB_HOST:?} -p ${LBDB_PORT:?} -x SCRIPT LOAD >${sha1_signature}; rc=$?
    fi

    case $rc in
        '0') [ -z "$DOIT" ] && echo "${fname} SHA1=[$(cat $sha1_signature)]" ;;
        *) warn "Failed to load ${fpath}"; let errors+=1 ;;
    esac
done
msg "Done"

[ $errors -gt 0 ] && { warn ${errors} errors; exit 2; }

exit 0

#
# __EOF__

