-- Extract next load-balanced URL using Round-Robin method.
--
-- IN:  KEYS[1] = segment KEY (Example: 'v1/20170504-03/33303992.ts')
-- IN:  ARGV[1] = pull this sensor to verify that URL's server is UP.
-- OUT: load-balanced URL for the segment.
--

local function get_sensor_value(url, stype)
    local i,j = string.find(url, "http://.+[0-9]+/")
    if not i then
        return nil, "#err: no host key for: " .. url
    end

    local hostk = string.sub(url, i, j)

    local alias = redis.call("HGET", "host_alias", hostk)
    if not alias then
        return nil, "#err: no host alias for " .. hostk
    end

    local sensor = "S" .. ":" .. stype .. ":" .. alias
    local val = redis.call("GET", sensor)
    if not val then
        return nil, "#err: no value for " .. sensor
    end

    return tonumber(val)
end


--
-- Main
--

local locK = "LOC:" .. KEYS[1]
local posK = "POS:" .. KEYS[1]
local sensor_type = ARGV[1]
if "-" == sensor_type then sensor_type = nil end

local num_urls = redis.call("ZCARD", locK)
if num_urls < 1 then
    return redis.error_reply("#err: empty " .. locK)
end

local pos = redis.call("INCR", posK)
if (pos >= num_urls) or (pos < 0) then pos = 0 end

if sensor_type then
    local p = tonumber(pos)
    local Urls = redis.call("ZRANGE", locK, 0, -1)
    local count = 0
    local found = false

    repeat
        local url = Urls[p + 1]
        if not url then
            return redis.error_reply("#err: nil URL at pos=" .. tostring(p + 1))
        end

        local metric = get_sensor_value(url, sensor_type)
        if metric then
            found = true
            break
        end

        p = p + 1
        if p >= num_urls then p = 0 end

        count = count + 1
    until count >= num_urls

    if not found then
        return redis.error_reply("#err: no values for [" .. sensor_type .. "] sensors")
    end

    pos = p
end

redis.call("SET", posK, pos)

return redis.call("ZRANGE", locK, pos, pos)


-- EOF --

